diff --git a/src/wp-admin/includes/class-wp-list-table.php b/src/wp-admin/includes/class-wp-list-table.php
index 791ee7c159..7736652ce4 100644
--- a/src/wp-admin/includes/class-wp-list-table.php
+++ b/src/wp-admin/includes/class-wp-list-table.php
@@ -166,8 +166,8 @@ class WP_List_Table {
 
 		if ( empty( $this->modes ) ) {
 			$this->modes = array(
-				'list'    => __( 'List View' ),
-				'excerpt' => __( 'Excerpt View' ),
+				'list'  => __( 'Compact view' ),
+				'extended' => __( 'Extended view' ),
 			);
 		}
 	}
@@ -517,6 +517,11 @@ class WP_List_Table {
 			return '';
 		}
 
+		$mode = get_user_setting( 'posts_list_mode', 'list' );
+		if ( 'extended' === $mode ) {
+			$always_visible = true;
+		}
+
 		$out = '<div class="' . ( $always_visible ? 'row-actions visible' : 'row-actions' ) . '">';
 		foreach ( $actions as $action => $link ) {
 			++$i;
diff --git a/src/wp-admin/includes/class-wp-screen.php b/src/wp-admin/includes/class-wp-screen.php
index e983ffef80..e87d17cf86 100644
--- a/src/wp-admin/includes/class-wp-screen.php
+++ b/src/wp-admin/includes/class-wp-screen.php
@@ -1293,12 +1293,7 @@ final class WP_Screen {
 			return;
 		}
 
-		$view_mode_post_types = get_post_types(
-			array(
-				'hierarchical' => false,
-				'show_ui'      => true,
-			)
-		);
+		$view_mode_post_types = get_post_types( array( 'show_ui' => true ) );
 
 		/**
 		 * Filters the post types that have different view mode options.
@@ -1306,7 +1301,7 @@ final class WP_Screen {
 		 * @since 4.4.0
 		 *
 		 * @param string[] $view_mode_post_types Array of post types that can change view modes.
-		 *                                       Default non-hierarchical post types with show_ui on.
+		 *                                       Default post types with show_ui on.
 		 */
 		$view_mode_post_types = apply_filters( 'view_mode_post_types', $view_mode_post_types );
 
@@ -1323,11 +1318,11 @@ final class WP_Screen {
 		<legend><?php _e( 'View Mode' ); ?></legend>
 				<label for="list-view-mode">
 					<input id="list-view-mode" type="radio" name="mode" value="list" <?php checked( 'list', $mode ); ?> />
-					<?php _e( 'List View' ); ?>
+					<?php _e( 'Compact view' ); ?>
 				</label>
 				<label for="excerpt-view-mode">
-					<input id="excerpt-view-mode" type="radio" name="mode" value="excerpt" <?php checked( 'excerpt', $mode ); ?> />
-					<?php _e( 'Excerpt View' ); ?>
+					<input id="excerpt-view-mode" type="radio" name="mode" value="extended" <?php checked( 'extended', $mode ); ?> />
+					<?php _e( 'Extended View' ); ?>
 				</label>
 		</fieldset>
 		<?php

diff --git a/src/wp-admin/includes/class-wp-posts-list-table.php b/src/wp-admin/includes/class-wp-posts-list-table.php
index 871feeb84e..71d218f416 100644
--- a/src/wp-admin/includes/class-wp-posts-list-table.php
+++ b/src/wp-admin/includes/class-wp-posts-list-table.php
@@ -178,7 +178,7 @@ class WP_Posts_List_Table extends WP_List_Table {
 		}
 
 		if ( ! empty( $_REQUEST['mode'] ) ) {
-			$mode = 'excerpt' === $_REQUEST['mode'] ? 'excerpt' : 'list';
+			$mode = 'extended' === $_REQUEST['mode'] ? 'extended' : 'list';
 			set_user_setting( 'posts_list_mode', $mode );
 		} else {
 			$mode = get_user_setting( 'posts_list_mode', 'list' );
@@ -1040,7 +1040,7 @@ class WP_Posts_List_Table extends WP_List_Table {
 		}
 		echo "</strong>\n";
 
-		if ( ! is_post_type_hierarchical( $this->screen->post_type ) && 'excerpt' === $mode && current_user_can( 'read_post', $post->ID ) ) {
+		if ( ! is_post_type_hierarchical( $this->screen->post_type ) && 'extended' === $mode && current_user_can( 'read_post', $post->ID ) ) {
 			if ( post_password_required( $post ) ) {
 				echo '<span class="protected-post-excerpt">' . esc_html( get_the_excerpt() ) . '</span>';
 			} else {
@@ -1100,7 +1100,7 @@ class WP_Posts_List_Table extends WP_List_Table {
 		 * @param string  $status      The status text.
 		 * @param WP_Post $post        Post object.
 		 * @param string  $column_name The column name.
 		 * @param string  $mode        The list display mode ('excerpt' or 'list').
 		 */
 		$status = apply_filters( 'post_date_column_status', $status, $post, 'date', $mode );
 
@@ -1108,11 +1108,11 @@ class WP_Posts_List_Table extends WP_List_Table {
 			echo $status . '<br />';
 		}
 
-		if ( 'excerpt' === $mode ) {
+		if ( 'extended' === $mode || 'excerpt' === $mode ) {
 			/**
 			 * Filters the published time of the post.
 			 *
 			 * If `$mode` equals 'excerpt', the published time and date are both displayed.
 			 * If `$mode` equals 'list' (default), the publish date is displayed, with the
 			 * time and date together available as an abbreviation definition.
 			 *
@@ -1121,7 +1121,7 @@ class WP_Posts_List_Table extends WP_List_Table {
 			 * @param string  $t_time      The published time.
 			 * @param WP_Post $post        Post object.
 			 * @param string  $column_name The column name.
 			 * @param string  $mode        The list display mode ('excerpt' or 'list').
 			 */
 			echo apply_filters( 'post_date_column_time', $t_time, $post, 'date', $mode );
 		} else {
@@ -1456,7 +1456,7 @@ class WP_Posts_List_Table extends WP_List_Table {
 	 *
 	 * @since 3.1.0
 	 *
-	 * @global string $mode List table view mode.
+	 * @global string $mode Compact table view mode.
 	 */
 	public function inline_edit() {
 		global $mode;
@@ -1496,7 +1496,7 @@ class WP_Posts_List_Table extends WP_List_Table {
 			}
 		}
 
-		$m            = ( isset( $mode ) && 'excerpt' === $mode ) ? 'excerpt' : 'list';
+		$m            = ( isset( $mode ) && 'extended' === $mode ) ? 'extended' : 'list';
 		$can_publish  = current_user_can( $post_type_object->cap->publish_posts );
 		$core_columns = array(
 			'cb'         => true,
@@ -1100,7 +1100,7 @@ class WP_Posts_List_Table extends WP_List_Table {
 		 * @param WP_Post $post        Post object.
 		 * @param string  $column_name The column name.
-		 * @param string  $mode        The list display mode ('excerpt' or 'list').
+		 * @param string  $mode        The list display mode ('extended' or 'list').
 		 */
 		$status = apply_filters( 'post_date_column_status', $status, $post, 'date', $mode );
@@ -1108,11 +1108,11 @@ class WP_Posts_List_Table extends WP_List_Table {
 			 * Filters the published time of the post.
 			 *
-			 * If `$mode` equals 'excerpt', the published time and date are both displayed.
+			 * If `$mode` equals 'extended', the published time and date are both displayed.
 			 * If `$mode` equals 'list' (default), the publish date is displayed, with the
 			 * time and date together available as an abbreviation definition.
@@ -1121,7 +1121,7 @@ class WP_Posts_List_Table extends WP_List_Table {
 			 * @param WP_Post $post        Post object.
 			 * @param string  $column_name The column name.
-			 * @param string  $mode        The list display mode ('excerpt' or 'list').
+			 * @param string  $mode        The list display mode ('extended' or 'list').
 			 */
 			echo apply_filters( 'post_date_column_time', $t_time, $post, 'date', $mode );